==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/script/rozdeleniosoby.js <==


ronPortal.rozdeleniOsoby = function() {
    var
        filtr = "",
        nactenyFiltr = "",
        nactenoVse = false,
        $shiftForm = null;
    function afterLoadData(responseData) {

        nactenyFiltr = responseData.data.filter;
        nactenoVse = responseData.data.nactenoVse;

        $("#InfoPocetRozdeleni").html(
            (responseData.data.count !== undefined)
                ? ron._("Celkovy_pocet_zaznamu") + ": <strong>" + responseData.data.count + "</strong>"
                : "");
    }


    function loadShiftFormData(param) {
        $("#InfoPocetRozdeleni").html(ron._("Probiha_vyhledavani"));
        $shiftForm.shiftform("loadData", param);
    }


    function fitPattern(item, pattern) {
        if (pattern === '') {
            return true;
        }

        if (item.popis) {
            let pomstr = item.popis.toUpperCase();
            if (pomstr.indexOf(pattern) >= 0) {
                return true;
            }
        }

        if (item.kod) {
            let pomstr = item.kod.toUpperCase();
            return pomstr.indexOf(pattern) >= 0;
        }
        return false;
    }
    var filterFunction = function (index, item) {
        return fitPattern(item, filtr);
    };


    var loadData = function (novyFiltr) {
        let
            dataNactena = false,
            newFiltr = novyFiltr.toUpperCase();

        if (nactenoVse) {
            let loadedfiltr = nactenyFiltr.toUpperCase();
            dataNactena = (loadedfiltr !== '') && newFiltr.indexOf(loadedfiltr) >= 0; // pokud je jiz nacteny filtr podretezcem noveho, tak neni potreba data nacitat znovu
        }

        filtr = newFiltr;

        if (dataNactena) {
            $shiftForm.shiftform("showData", filterFunction);
        } else {
            loadShiftFormData("filter=" + novyFiltr)
        }
    };


    var filtrujRozdeleniOsoby = function (event) // onkeyup
    {
        var zadanyFiltr = $("#filtrrozdeleni").val();

        if (event.which == 13 && zadanyFiltr.length >= 3) {
            loadShiftFormData("force=1");
        }

        if (zadanyFiltr == filtr) {
            return;
        }

        $("#vyhledatRozdeleni").prop("disabled", zadanyFiltr.length < 3);

        setTimeout( // timeout kvuli lepsi odezve
            function () {
                loadData(zadanyFiltr);
            }, 100
        );
    };
    var filtrRozdeleniOsobyKeyPress = function (event) // onkeypress
    {
        if (event.which == 13) return false; // zahodi enter - aby se nezavrelo okno
        return true;
    };


    var closeDialog = function() {
        $("#rozdeleniosobydialog").dialog("close");
    };


    var dblClickItem = null; // pouzije se jako parametr callBack funkce volane pri zavreni okna

    var onRightDblClick = function() {
        var index = $(this).data("rontable-index");
        dblClickItem = $shiftForm.shiftform("instance").options.data.rightItems[index].kod;
        closeDialog();
    };



    var onLeftDblClick = function() {
        var index = $(this).data("rontable-index");
        dblClickItem = $shiftForm.shiftform("instance").options.data.leftItems[index].kod;
        $shiftForm.shiftform("moveRight", [index], function() {
            closeDialog();
            return false; // aby zbytecne nerefreshoval obsah shiftformu
        });
    };
    return function (options) {
        if (typeof options === "function") {
            options = { closeCallback: options };
        } else if (!options) {
            options = {};
        }

        var onClose = function() {
            if (options.closeCallback) {
                options.closeCallback(dblClickItem);
            }
        };

        if (!$shiftForm) {
            var
                $left = $("#NeprirazeneRozdeleni"),
                $right = $("#PrirazeneRozdeleni");
            $shiftForm = $("#rozdeleniosobydialog").shiftform({
                $leftTable: $left,
                $rightTable: $right,
                leftColumns: ["kod", "popis"],
                rightColumns: ["kod", "popis"],
                afterLoadData: afterLoadData,
                url: options.url
            });


            $left
                .on("dblclick", "tr", onLeftDblClick);

            $right
                .on("dblclick", "tr", onRightDblClick);

            $("#filtrrozdeleni")
                .on("keyup", filtrujRozdeleniOsoby)
                .on("keypress", filtrRozdeleniOsobyKeyPress);

            $("#zrusRozdeleniOsoby")
                .on("click", function () {
                    $shiftForm.shiftform("moveLeft");
                    return false;
                });

            $("#priradRozdeleniOsoby")
                .on("click", function () {
                    $shiftForm.shiftform("moveRight");
                    return false;
                });

            $("#vyhledatRozdeleni")
                .on("click", function () {
                    loadShiftFormData("filter=" + filtr + "&force=1");
                });

            $("#RozdeleniOK")
                .on("click", function() {
                    closeDialog();
                });
        } else if (options.url) {
            $shiftForm.shiftform("setUrl", options.url);
        }


        $("#rozdeleniosobydialog").dialog({
            modal: true,
            resizable: false,
            width: "auto",
            height: "auto",
            close: onClose,
            url: options.url
        });

        setTimeout(function () { // timeout kvuli lepsi odezve
            loadShiftFormData(null);
        }, 100);

        $("#filtrrozdeleni")
            .val("")
            .focus();
    };
}();
ronPortal.aktualizujRozdeleniOsoby = function(url, idpp, $selectKod, $selectPopis, newValue, callback) {
    function createRozdeleniSelectItems($select, items, pouzeKod) {
        let
            value = newValue ? newValue : $select.val(),
            newValueFound = false;

        $select.empty();
        $("<option/>")
            .attr("value", "")
            .appendTo($select);

        if (!value) {
            newValueFound = true;
        }

        for (let i = 0; i < items.length; i++) {
            if ($select) {
                $("<option/>")
                    .attr("value", items[i].kod)
                    .text(pouzeKod ? items[i].kod : items[i].popis)
                    .attr("class", items[i].cssClass ? items[i].cssClass : '')
                    .attr("title", pouzeKod ? items[i].popis : items[i].kod)
                    .appendTo($select);
            }

            if (items[i].kod == value) newValueFound = true;
        }

        if ( !newValueFound ) {
            $("<option/>")
                .attr("value", value)
                .text(value)
                .appendTo($select);
        }

        $select.val(value);

        if ($select.is(".ronselect")) {
            $select.ronselect("reloadItems");
        }
    }

    $.ajax( url + "&shiftformaction=loaddata&jenvlastni=1&idpp=" + idpp )
        .done( function(responseData) {
            if ( !responseData ) {
                return;
            }

            if ( responseData.result === 'OK' ) {
                for (let i = 0;  i < $selectPopis.length;  i++) {
                    createRozdeleniSelectItems($selectPopis[i], responseData.data.rightItems, false); // i popis
                }
                responseData.data.rightItems.sort( function(item1, item2) {
                    return item1.kod.localeCompare(item2.kod);
                } );

                for (let i = 0;  i < $selectKod.length;  i++) {
                    createRozdeleniSelectItems($selectKod[i], responseData.data.rightItems, true); // jen kod
                }

                if (callback) callback(newValue);
            }
            else {
                ron.showError(responseData);
            }

        }).fail( function(jqXHR) {
            ron.showAjaxError(jqXHR, "Chyba pri nacitani seznamu rozdeleni!");
        });
};
ronPortal.rozdeleniOsoby_DVHromadne = function(idpp) {
    var aktualizujSelect = function(newValue) {
        ronPortal.aktualizujRozdeleniOsoby(
            '?menuid=editace&action=rozdeleniosoby',
            idpp,
            [$("#vyberRozdeleni")], [$("#vyberRozdeleniPopis")],
            newValue);
    };

    ronPortal.rozdeleniOsoby(aktualizujSelect);
};

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/script/rozdeleniosoby.js <==


ronPortal.rozdeleniOsoby = function() {
    var
        filtr = "",
        nactenyFiltr = "",
        nactenoVse = false,
        $shiftForm = null;
    function afterLoadData(responseData) {

        nactenyFiltr = responseData.data.filter;
        nactenoVse = responseData.data.nactenoVse;

        $("#InfoPocetRozdeleni").html(
            (responseData.data.count !== undefined)
                ? ron._("Celkovy_pocet_zaznamu") + ": <strong>" + responseData.data.count + "</strong>"
                : "");
    }


    function loadShiftFormData(param) {
        $("#InfoPocetRozdeleni").html(ron._("Probiha_vyhledavani"));
        $shiftForm.shiftform("loadData", param);
    }


    function fitPattern(item, pattern) {
        if (pattern === '') {
            return true;
        }

        if (item.popis) {
            let pomstr = item.popis.toUpperCase();
            if (pomstr.indexOf(pattern) >= 0) {
                return true;
            }
        }

        if (item.kod) {
            let pomstr = item.kod.toUpperCase();
            return pomstr.indexOf(pattern) >= 0;
        }
        return false;
    }
    var filterFunction = function (index, item) {
        return fitPattern(item, filtr);
    };


    var loadData = function (novyFiltr) {
        let
            dataNactena = false,
            newFiltr = novyFiltr.toUpperCase();

        if (nactenoVse) {
            let loadedfiltr = nactenyFiltr.toUpperCase();
            dataNactena = (loadedfiltr !== '') && newFiltr.indexOf(loadedfiltr) >= 0; // pokud je jiz nacteny filtr podretezcem noveho, tak neni potreba data nacitat znovu
        }

        filtr = newFiltr;

        if (dataNactena) {
            $shiftForm.shiftform("showData", filterFunction);
        } else {
            loadShiftFormData("filter=" + novyFiltr)
        }
    };


    var filtrujRozdeleniOsoby = function (event) // onkeyup
    {
        var zadanyFiltr = $("#filtrrozdeleni").val();

        if (event.which == 13 && zadanyFiltr.length >= 3) {
            loadShiftFormData("force=1");
        }

        if (zadanyFiltr == filtr) {
            return;
        }

        $("#vyhledatRozdeleni").prop("disabled", zadanyFiltr.length < 3);

        setTimeout( // timeout kvuli lepsi odezve
            function () {
                loadData(zadanyFiltr);
            }, 100
        );
    };
    var filtrRozdeleniOsobyKeyPress = function (event) // onkeypress
    {
        if (event.which == 13) return false; // zahodi enter - aby se nezavrelo okno
        return true;
    };


    var closeDialog = function() {
        $("#rozdeleniosobydialog").dialog("close");
    };


    var dblClickItem = null; // pouzije se jako parametr callBack funkce volane pri zavreni okna

    var onRightDblClick = function() {
        var index = $(this).data("rontable-index");
        dblClickItem = $shiftForm.shiftform("instance").options.data.rightItems[index].kod;
        closeDialog();
    };



    var onLeftDblClick = function() {
        var index = $(this).data("rontable-index");
        dblClickItem = $shiftForm.shiftform("instance").options.data.leftItems[index].kod;
        $shiftForm.shiftform("moveRight", [index], function() {
            closeDialog();
            return false; // aby zbytecne nerefreshoval obsah shiftformu
        });
    };
    return function (options) {
        if (typeof options === "function") {
            options = { closeCallback: options };
        } else if (!options) {
            options = {};
        }

        var onClose = function() {
            if (options.closeCallback) {
                options.closeCallback(dblClickItem);
            }
        };

        if (!$shiftForm) {
            var
                $left = $("#NeprirazeneRozdeleni"),
                $right = $("#PrirazeneRozdeleni");
            $shiftForm = $("#rozdeleniosobydialog").shiftform({
                $leftTable: $left,
                $rightTable: $right,
                leftColumns: ["kod", "popis"],
                rightColumns: ["kod", "popis"],
                afterLoadData: afterLoadData,
                url: options.url
            });


            $left
                .on("dblclick", "tr", onLeftDblClick);

            $right
                .on("dblclick", "tr", onRightDblClick);

            $("#filtrrozdeleni")
                .on("keyup", filtrujRozdeleniOsoby)
                .on("keypress", filtrRozdeleniOsobyKeyPress);

            $("#zrusRozdeleniOsoby")
                .on("click", function () {
                    $shiftForm.shiftform("moveLeft");
                    return false;
                });

            $("#priradRozdeleniOsoby")
                .on("click", function () {
                    $shiftForm.shiftform("moveRight");
                    return false;
                });

            $("#vyhledatRozdeleni")
                .on("click", function () {
                    loadShiftFormData("filter=" + filtr + "&force=1");
                });

            $("#RozdeleniOK")
                .on("click", function() {
                    closeDialog();
                });
        } else if (options.url) {
            $shiftForm.shiftform("setUrl", options.url);
        }


        $("#rozdeleniosobydialog").dialog({
            modal: true,
            resizable: false,
            width: "auto",
            height: "auto",
            close: onClose,
            url: options.url
        });

        setTimeout(function () { // timeout kvuli lepsi odezve
            loadShiftFormData(null);
        }, 100);

        $("#filtrrozdeleni")
            .val("")
            .focus();
    };
}();
ronPortal.aktualizujRozdeleniOsoby = function(url, idpp, $selectKod, $selectPopis, newValue, callback) {
    function createRozdeleniSelectItems($select, items, pouzeKod) {
        let
            value = newValue ? newValue : $select.val(),
            newValueFound = false;

        $select.empty();
        $("<option/>")
            .attr("value", "")
            .text(" ")
            .appendTo($select);

        if (!value) {
            newValueFound = true;
        }

        for (let i = 0; i < items.length; i++) {
            if ($select) {
                $("<option/>")
                    .attr("value", items[i].kod)
                    .text(pouzeKod ? items[i].kod : items[i].popis)
                    .attr("class", items[i].cssClass ? items[i].cssClass : '')
                    .attr("title", pouzeKod ? items[i].popis : items[i].kod)
                    .attr("data-popis", items[i].popis)
                    .appendTo($select);
            }

            if (items[i].kod == value) {
                newValueFound = true;
            }
        }

        if ( !newValueFound ) {
            $("<option/>")
                .attr("value", value)
                .text(value)
                .appendTo($select);
        }

        $select.val(value);

        if ($select.is(".ronselect")) {
            $select.ronselect("reloadItems");
        }
    }

    $.ajax( url + "&shiftformaction=loaddata&jenvlastni=1&idpp=" + idpp )
        .done( function(responseData) {
            if ( !responseData ) {
                return;
            }

            if ( responseData.result === 'OK' ) {
                for (let i = 0;  i < $selectPopis.length;  i++) {
                    createRozdeleniSelectItems($selectPopis[i], responseData.data.rightItems, false); // i popis
                }
                responseData.data.rightItems.sort( function(item1, item2) {
                    return item1.kod.localeCompare(item2.kod);
                } );

                for (let i = 0;  i < $selectKod.length;  i++) {
                    createRozdeleniSelectItems($selectKod[i], responseData.data.rightItems, true); // jen kod
                }

                if (callback) callback(newValue);
            }
            else {
                ron.showError(responseData);
            }

        }).fail( function(jqXHR) {
            ron.showAjaxError(jqXHR, "Chyba pri nacitani seznamu rozdeleni!");
        });
};


$(function() {
    function vyberRozdeleniOsobyClick() {
        let
            $that = $(this);

        function aktualizujSelect(newValue) {
            ronPortal.aktualizujRozdeleniOsoby(
                $that.data("url"),
                $that.data("idpp"),
                [$($that.data("select-kod"))], [$($that.data("select-popis"))],
                newValue);
        }

        ronPortal.rozdeleniOsoby(aktualizujSelect);
    }


    $("body")
        .on("click", ".vyber-rozdeleni-osoby", vyberRozdeleniOsobyClick);
})
